#
# spec file for package m17n-lib
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define	appdefdir  %{_datadir}/X11
Name:           m17n-lib
Version:        1.8.4
Release:        1.7
Summary:        Multilingual Text Processing Library for the C Language
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://www.nongnu.org/m17n/
Source0:        http://download.savannah.gnu.org/releases/m17n/%{name}-%{version}.tar.gz
Source1:        m17n-lib-rpmlintrc
Source2:        baselibs.conf
BuildRequires:  fdupes
BuildRequires:  libotf-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gdlib)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(m17n-db)
BuildRequires:  pkgconfig(wordcut)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xft)

%description
A multilingual text processing library for the C language.
This package contains m17n-* programs.

%package -n libm17n0
Summary:        Multilingual text processing library for the C language
Group:          System/Libraries
Requires:       pkgconfig(m17n-db)

%description -n libm17n0
A multilingual text processing library for the C language.
This package contains shared libraries.

%package devel
Summary:        Multilingual text processing library for the C language
Group:          Development/Libraries/C and C++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xft)
Requires:       %{name} = %{version}
Requires:       glibc-devel

%description devel
A multilingual text processing library for the C language

%prep
%setup -q

%build
%configure \
  --disable-static
# Not thread safe at all
%make_build -j1

%check
export MALLOC_CHECK_=2
%make_build -j1 check
unset MALLOC_CHECK_

%install
%make_install INSTALL="install -p"
# Japanese app-defaults:
mkdir -p %{buildroot}%{appdefdir}/{ja,ja_JP,ja_JP.eucJP,ja_JP.SJIS,ja_JP.UTF-8}/app-defaults
iconv -f UTF-8 -t EUC-JP < example/M17NEdit.ja \
      > %{buildroot}%{appdefdir}/ja/app-defaults/M17NEdit
iconv -f UTF-8 -t EUC-JP < example/M17NEdit.ja \
      > %{buildroot}%{appdefdir}/ja_JP/app-defaults/M17NEdit
iconv -f UTF-8 -t EUC-JP < example/M17NEdit.ja \
      > %{buildroot}%{appdefdir}/ja_JP.eucJP/app-defaults/M17NEdit
iconv -f UTF-8 -t SJIS < example/M17NEdit.ja \
      > %{buildroot}%{appdefdir}/ja_JP.SJIS/app-defaults/M17NEdit
iconv -f UTF-8 -t UTF-8 < example/M17NEdit.ja \
      > %{buildroot}%{appdefdir}/ja_JP.UTF-8/app-defaults/M17NEdit
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print

%fdupes %{buildroot}

%post -n libm17n0 -p /sbin/ldconfig
%postun -n libm17n0 -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS NEWS README ChangeLog
%{_bindir}/*
%dir %{appdefdir}/??
%dir %{appdefdir}/??_*
%dir %{appdefdir}/*/app-defaults
%{appdefdir}/*/app-defaults/M17NEdit

%files -n libm17n0
%{_libdir}/lib*.so.*
%{_libdir}/m17n

%files devel
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Sat Oct 14 2023 Matthias Eliasson <elimat@opensuse.org>
- update to 1.8.4:
  This release is just for bug fixing.
  * Fix “typedef in m17n-core.h causing error when compiling with C++ code”
- Remove RPM groups
- Change URL to new upstream site.
- Examples are now in UTF-8 encoding so change iconv part accordingly
* Mon Aug 24 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.8.0:
  This release is just for bug fixing.
- remove m17n-lib-1.7.0-fix-crash-in-marathi-transliteration.patch,
  m17n-lib-fix-warnings.diff: upstream
* Sat Aug 12 2017 jengelh@inai.de
- Fix RPM groups.
* Wed Aug  9 2017 tchvatal@suse.com
- Drop ispell dependency wrt fate#323578 rh dropped the same subpkg
  in 2011
- Cleanup the dependencies to not pull in full x11 suite and depend
  only on the required libs
- Build with --as-needed
- Format with spec-cleaner
* Wed Dec  7 2016 maiku.fabian@gmail.com
- Fix crash in Marathi transliteration:
  m17n-lib-1.7.0-fix-crash-in-marathi-transliteration.patch
  See also:
  https://lists.nongnu.org/archive/html/m17n-list/2015-08/msg00001.html
  https://lists.nongnu.org/archive/html/m17n-list/2015-08/msg00002.html
* Sun Mar  1 2015 p.drouand@gmail.com
- Update to version 1.7.0
  * The mechanism of fallback input method is implemented.  For that, a
    new variable fallback-input-method and new commands switch-im,
    push-im, pop-im are supported.
* Mon Jul  1 2013 i@marguerite.su
- update version 1.6.4
  * no change, just update version number
* Mon Mar 18 2013 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-2.0+
  Consolidate - the GPL-2.0+ is only included because of test scripts (e.g.
  src/linkcore.c).
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Tue Jan 31 2012 tiwai@suse.de
- updated to version 1.6.3:
  Minor bugs fixed and several new input methods added, including
  the segfault fix with VLC
* Tue Aug  2 2011 tiwai@suse.de
- Update to version 1.6.2: bug fix release; see ChangeLog
- Fix compile warnings
- Split libm17n0 subpackage for shared libraries
- Add baselibs.conf
* Mon May 17 2010 coolo@novell.com
- do not require anthy, it creates a build cycle with emacs
* Thu Apr 22 2010 tiwai@suse.de
- updated to version 1.6.0:
  requires the new libotf; plugin locations changed
* Mon Oct 27 2008 mfabian@suse.de
- update to m17n-lib 1.5.3.
  • only bugfixes.
* Fri Jun 13 2008 crrodriguez@suse.de
- disable unusable static libraries
* Thu Feb 28 2008 schwab@suse.de
- Update to m17n-lib 1.5.1.
  * New API layer FLT is created.
  * New environment variable MDEBUG_FLT is available to turn on
    printing debug information for FLT, and these are now obsolete;
    MDEBUG_FONT_FLT, MDEBUG_FONT_OTF.
  * New functions mchartable_min_char () returns the mininum character.
    that is set some value in a char-table.  New funcion
    mchartable_min_char () is for the maximum character.
* Wed Sep  5 2007 mfabian@suse.de
- add extra BuildRequires for SUSE_Linux_10.0 repository in the
  openSUSE build service.
* Wed Aug  1 2007 mfabian@suse.de
- update to 1.4.0:
  • New function msymbol_put_func (), msymbol_get_func
    (), mplist_put_func (), mplist_get_func (),
    mface_put_hook (), and mface_get_hook () are
    available to avoid unsafe casting of function
    pointer.  New macro M17N_FUNC and new type
    M17NFunc are also introduced.
- remove bugzilla-232303-local-variable-used-before-set.patch
  (was from upstream CVS).
- add -fno-strict-aliasing .
- add gd-devel to BuildRequires.
* Thu May 24 2007 ro@suse.de
- added ldconfig to post scripts
* Tue Jan  9 2007 mfabian@suse.de
- update to 1.3.4.
- fix bugzilla #32303.
* Sun Oct 29 2006 meissner@suse.de
- build with RPM_OPT_FLAGS. Added some requires to -devel package.
* Mon Aug 28 2006 mfabian@suse.de
- update to 1.3.3.20060828 (fixes bugzilla #199870).
  • If the environment variable "M17NDIR" is not set, the
    directory "~/.m17n.d" is serched for database files.
  • New function mfont_list_family_names () returns a list of
    available font family names.
  • New functions mlanguage_list (), mlanguage_code (),
    mlanguage_name (), and mlanguage_text () return various
    language-related information.
  • New functions mscript_list () and mscript_language_list ()
    return various script-related information.
* Mon Aug 14 2006 mfabian@suse.de
- move app-defaults to /usr/share/X11 (for X11R7).
* Tue Jun 20 2006 mfabian@suse.de
- update to 1.3.3.20060620:
  fixes bugzilla #185572 and some other small bugs.
- install Japanese app-defaults.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 mfabian@suse.de
- update to 1.3.0.20060113 (CVS HEAD).
* Fri Jan 13 2006 mfabian@suse.de
- update to 1.3.0.
- add pkgconfig to # neededforbuild.
* Fri Jan 14 2005 mfabian@suse.de
- add "ispell words ispell-british" to "# neededforbuild" to
  make the ispell input method work.
* Tue Dec 28 2004 mfabian@suse.de
- update to 1.2.0.
* Tue Dec 21 2004 mfabian@suse.de
- update to 1.1.0.20041221 (cvs version) to test the new
  minput_reset_ic() function.
* Thu Sep 30 2004 mfabian@suse.de
- add "Requires: m17n-db". m17n-lib is almost useless without
  m17n-db and scim-m17n doesn't work at all without m17n-db.
* Mon Sep 20 2004 mfabian@suse.de
- Bugzilla #45562: move .so files to main package. scim-m17n needs
  the  .so files but it should not need to require m17n-devel.
* Fri Aug 20 2004 mfabian@suse.de
- Bugzilla #44028: rename binaries from m* to m17n-* to remove
  conflict with majordomo's /usr/bin/medit.
* Tue Aug 17 2004 mfabian@suse.de
- update to 1.1.0.
- remove Zhe Su's patch m17n-lib-typedef.diff (included upstream).
- remove my useless-header.patch (included upstream).
* Mon Aug 16 2004 mfabian@suse.de
- new package: m17n-lib, version 1.0.2
